<?php

function getBody2($uid, $imap, $structure) {
	$body = get_part($imap, $uid, "TEXT/PLAIN", $structure);
	// if HTML body is empty, try getting text body
	if ($body == "") {
		$body = get_part($imap, $uid, "TEXT/HTML",$structure);
	}
	return $body;
	
}


function getBody($uid, $imap) {
	$body = get_part($imap, $uid, "TEXT/HTML");
	// if HTML body is empty, try getting text body
	if ($body == "") {
		$body = get_part($imap, $uid, "TEXT/PLAIN");
	}
	return $body;
}

function get_part($imap, $uid, $mimetype, $structure = false, $partNumber = false) {
	if (!$structure) {
		$structure = imap_fetchstructure($imap, $uid, FT_UID);
	}
	
	if ($structure) {
		if ($mimetype == get_mime_type($structure)) {
			if (!$partNumber) {
				$partNumber = 1;
			}
			$text = imap_fetchbody($imap, $uid, $partNumber, FT_UID);
			switch ($structure->encoding) {
				case 3: return imap_base64($text);
				case 4: return imap_qprint($text);
				default: return $text;
			}
		}

		// multipart
		if ($structure->type == 1) {
			foreach ($structure->parts as $index => $subStruct) {
				$prefix = "";
				if ($partNumber) {
					$prefix = $partNumber . ".";
				}
				$data = get_part($imap, $uid, $mimetype, $subStruct, $prefix . ($index + 1));
				if ($data) {
					return $data;
				}
			}
		}
	}
	return false;
}

function get_mime_type($structure) {
	$primaryMimetype = array("TEXT", "MULTIPART", "MESSAGE", "APPLICATION", "AUDIO", "IMAGE", "VIDEO", "OTHER");

	if ($structure->subtype) {
		return $primaryMimetype[(int)$structure->type] . "/" . $structure->subtype;
	}
	return "TEXT/PLAIN";
}
function downloadAttachment($imap, $uid, $partNum, $encoding, $path) {
	$partStruct = imap_bodystruct($imap, imap_msgno($imap, $uid), $partNum);
	$filename = $partStruct->dparameters[0]->value;
	$message = imap_fetchbody($imap, $uid, $partNum, FT_UID);

	switch ($encoding) {
		case 0:
		case 1:
			$message = imap_8bit($message);
			break;
		case 2:
			$message = imap_binary($message);
			break;
		case 3:
			$message = imap_base64($message);
			break;
		case 4:
			$message = quoted_printable_decode($message);
			break;
	}

	header("Content-Description: File Transfer");
	header("Content-Type: application/octet-stream");
	header("Content-Disposition: attachment; filename=" . $filename);
	header("Content-Transfer-Encoding: binary");
	header("Expires: 0");
	header("Cache-Control: must-revalidate");
	header("Pragma: public");
	echo $message;

}

function saveAttachment($imap, $uid, $partNum, $encoding, $path, $attachmentName) {
	$msgno = imap_msgno($imap, $uid);
	
	if ($msgno == 0) $msgno = $uid;	
	$partStruct = imap_bodystruct($imap, $msgno, $partNum);
	$filename = $partStruct->dparameters[0]->value;
	$message = imap_fetchbody($imap, $uid, $partNum, FT_UID);

	switch ($encoding) {
		case 0:
		case 1:
			$message = imap_8bit($message);
			break;
		case 2:
			$message = imap_binary($message);
			break;
		case 3:
			$message = imap_base64($message);
			break;
		case 4:
			$message = quoted_printable_decode($message);
			break;
	}
	
	$fdw = fopen($path ."/". $attachmentName, "w+");
	fwrite($fdw, $message);
	fclose($fdw);

}


function getAttachments($imap, $mailNum, $part, $partNum) {
	
	$attachments = array();
	

	if (isset($part->parts)) {
		foreach ($part->parts as $key => $subpart) {
			
			
			if($partNum != "") {
				$newPartNum = $partNum . "." . ($key + 1);
			}
			else {
				$newPartNum = ($key+1);
			}
				
			$result = getAttachments($imap, $mailNum, $subpart,$newPartNum);
			if (count($result) != 0) {
				array_push($attachments, $result);
			}
		}
	}
	else if (isset($part->disposition)) {
		if ( strtoupper($part->disposition) == "ATTACHMENT") {
			$partStruct = imap_bodystruct($imap, $mailNum,
					$partNum);
			$attachmentDetails = array(
					"name"    => $part->dparameters[0]->value,
					"partNum" => $partNum,
					"enc"     => $partStruct->encoding
			);
			return $attachmentDetails;
		}
	}

	return $attachments;
}
function openimap(){
	global $cfg;
	if (extension_loaded("imap")) {
		if ($cfg["FETCH_MAILSERVER"]!="") {
			$mailbox = "{".$cfg["FETCH_MAILSERVER"].":".$cfg["FETCH_PORT"]."/".$cfg["FETCH_PROTO"].$cfg["FETCH_PROTOOPTS"]."}INBOX";
			$user = $cfg["FETCH_USER"];
			$pass = $cfg["FETCH_PASSWD"];
			$imap = @imap_open($mailbox, $user, $pass)  or die();
			//$imap = @imap_open($mailbox, $user, $pass, NULL, 1, array('DISABLE_AUTHENTICATOR' => 'GSSAPI'))  or die('Error : ' . imap_last_error());;
			$error="";
		} else {
			$error="Mailbox not defined - see config options.";
			$imap="";
		}
	} else {
		$error="php[]-imap not loaded";
		$imap="";		
	}
	
	return array($imap, $error);
}


function explodeBody($bodyText){
	$einzel=explode("\n", trim($bodyText));
	for ($i = 0; $i < 4; $i++) {
		if (!isset($einzel[$i])){
			$einzel[$i] ="";
		}
	}
	
	return $einzel;
}











